#line 2 "bootscanner.c"

#line 4 "bootscanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer boot_yy_create_buffer
#define yy_delete_buffer boot_yy_delete_buffer
#define yy_flex_debug boot_yy_flex_debug
#define yy_init_buffer boot_yy_init_buffer
#define yy_flush_buffer boot_yy_flush_buffer
#define yy_load_buffer_state boot_yy_load_buffer_state
#define yy_switch_to_buffer boot_yy_switch_to_buffer
#define yyin boot_yyin
#define yyleng boot_yyleng
#define yylex boot_yylex
#define yylineno boot_yylineno
#define yyout boot_yyout
#define yyrestart boot_yyrestart
#define yytext boot_yytext
#define yywrap boot_yywrap
#define yyalloc boot_yyalloc
#define yyrealloc boot_yyrealloc
#define yyfree boot_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE boot_yyrestart(boot_yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int boot_yyleng;

extern FILE *boot_yyin, *boot_yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up boot_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up boot_yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via boot_yyrestart()), so that the user can continue scanning by
	 * just pointing boot_yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when boot_yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int boot_yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow boot_yywrap()'s to do buffer switches
 * instead of setting up a fresh boot_yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void boot_yyrestart (FILE *input_file  );
void boot_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE boot_yy_create_buffer (FILE *file,int size  );
void boot_yy_delete_buffer (YY_BUFFER_STATE b  );
void boot_yy_flush_buffer (YY_BUFFER_STATE b  );
void boot_yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void boot_yypop_buffer_state (void );

static void boot_yyensure_buffer_stack (void );
static void boot_yy_load_buffer_state (void );
static void boot_yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER boot_yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE boot_yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE boot_yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE boot_yy_scan_bytes (yyconst char *bytes,int len  );

void *boot_yyalloc (yy_size_t  );
void *boot_yyrealloc (void *,yy_size_t  );
void boot_yyfree (void *  );

#define yy_new_buffer boot_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        boot_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            boot_yy_create_buffer(boot_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        boot_yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            boot_yy_create_buffer(boot_yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define boot_yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *boot_yyin = NULL, *boot_yyout = NULL;

typedef int yy_state_type;

extern int boot_yylineno;

int boot_yylineno = 1;

extern char *boot_yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr boot_yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up boot_yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	boot_yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 34
#define YY_END_OF_BUFFER 35
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[163] =
    {   0,
        0,    0,   35,   33,   16,   15,   17,   33,   13,   14,
       11,   28,   33,   28,   12,   28,   28,   33,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   18,
        0,   29,   28,    0,   28,    0,   31,   30,   28,   28,
       28,    0,   28,    0,   28,   28,   28,   28,   28,   28,
       28,   24,   28,   28,   28,   28,   28,   28,   28,   18,
       28,    0,   30,    0,    0,   28,   28,    0,   27,    4,
        0,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,    0,   31,    0,
        0,   30,   32,   28,   28,   28,   28,   28,   28,   28,

       28,   28,    1,   28,   28,   28,   28,   28,   28,    0,
       30,   28,   28,   20,    2,   28,   28,   23,   28,   28,
       28,   28,   26,   28,   25,   28,    9,   28,    3,   28,
       28,   10,   28,   28,   22,   28,   28,   19,   21,   28,
       28,   28,   28,   28,   28,   28,    5,   28,   28,   28,
       28,   28,   28,    8,   28,   28,   28,    7,   28,   28,
        6,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    6,    1,    1,    1,    1,    7,
        8,    1,    9,   10,   11,   12,    1,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,    1,    1,    1,
       14,    1,    1,    1,   15,   15,   15,   16,   17,   15,
       15,   15,   18,   15,   15,   15,   15,   15,   19,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       20,   21,   22,    1,   23,    1,   24,   25,   26,   27,

       28,   15,   29,   30,   31,   15,   15,   32,   15,   33,
       34,   35,   36,   37,   38,   39,   40,   15,   41,   42,
       43,   15,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[44] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        3,    3,    3,    1,    3,    3,    3,    3,    3,    4,
        3,    1,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3
    } ;

static yyconst flex_uint16_t yy_base[167] =
    {   0,
        0,  384,  332,  460,  460,  460,  460,  307,  460,  460,
      460,   32,  290,   43,  460,   37,   54,  273,   56,   58,
       48,   53,   50,   61,   12,   69,   57,   72,   73,    0,
      271,  460,   38,  249,  102,  247,   34,  103,  105,   68,
      115,  112,   95,  192,   87,   98,  106,  102,  113,  117,
      125,  110,  120,  127,  132,  140,  139,  144,  137,    0,
      174,  179,  176,  185,  189,  187,  169,  184,  460,  167,
      178,  178,  177,  181,  185,  190,  188,  198,  199,  201,
      197,  206,  210,  211,  219,  224,  244,  168,  156,  257,
      149,  145,   87,  229,  233,  215,  244,  240,  251,  247,

      256,  258,  243,  254,  265,  267,  268,  275,  276,   73,
       60,  277,  279,  280,  287,  294,  289,  290,  297,  299,
      301,  313,  308,  315,  310,  311,  312,  320,  322,  330,
      325,  327,  338,  345,  335,  337,  349,  340,  347,  359,
      354,  361,  362,  352,  370,  366,  369,  374,  379,  381,
      389,  393,  391,  386,  396,  394,  406,  404,  405,  408,
      409,  460,  449,   58,  451,  455
    } ;

static yyconst flex_int16_t yy_def[167] =
    {   0,
      162,    1,  162,  162,  162,  162,  162,  163,  162,  162,
      162,  164,  162,  165,  162,  165,  165,  162,  165,  165,
       20,   20,   20,   20,   20,   20,   20,   20,   20,  166,
      163,  162,  164,  162,  164,  162,  162,  162,   20,   20,
       20,  162,   20,  162,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,  166,
      164,  162,  162,  162,  162,  164,   20,  162,  162,   20,
      162,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,  164,  162,  162,  162,
      162,  162,  162,   20,   20,   20,   20,   20,   20,   20,

       20,   20,   20,   20,   20,   20,   20,   20,   20,  162,
      162,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,    0,  162,  162,  162,  162
    } ;

static yyconst flex_uint16_t yy_nxt[504] =
    {   0,
        4,    5,    6,    7,    8,    4,    9,   10,    4,   11,
       12,   13,   14,   15,   16,   16,   16,   16,   17,    4,
       18,    4,   19,   16,   20,   21,   22,   16,   16,   16,
       23,   16,   16,   24,   16,   16,   25,   26,   27,   28,
       29,   16,   16,   34,   35,   54,   37,   33,  162,  162,
       62,   40,   36,   33,   38,   39,   42,   36,   36,   41,
       33,   62,   42,   36,   33,  162,   33,  162,   33,  162,
       41,   43,  111,   42,   36,   42,   36,   42,   36,   48,
       50,   40,   51,   40,   49,  111,   40,   40,   45,   40,
       56,   46,   40,   52,   40,   53,   40,   47,   55,   93,

       40,   40,   40,   59,   57,   40,   40,   40,   40,   58,
       70,   40,   40,   38,   35,   63,   38,   39,   61,   64,
       40,   41,   36,   65,   68,   66,   72,   67,   40,   61,
       64,   73,   41,   69,   40,   75,   74,   40,   40,   40,
       76,   40,   77,   40,   40,   40,   40,   80,   40,   40,
       40,   78,   40,   40,   40,   82,   40,   92,   40,   40,
       40,   92,   79,   83,   40,   40,   40,   81,   89,   84,
       40,   40,   40,   40,   85,   86,   40,   40,   40,   40,
       89,   67,   65,   40,   66,  162,   87,   88,   63,   88,
       33,   89,   90,   91,   36,   91,   68,   92,  162,   87,

       40,   93,   40,   90,   71,   69,   40,   36,   40,   94,
       40,   40,   96,   98,   40,   95,   40,   40,   40,   99,
       40,   40,   97,   40,   40,  100,  102,   40,  101,   40,
       40,   40,   40,  103,   40,  104,   40,   40,   40,   40,
       40,  114,  105,   40,   40,   40,  107,  106,   40,   40,
       40,  108,   40,  109,   40,  162,   87,   40,   40,   44,
      112,   37,   40,   40,   36,  110,   40,  110,   40,  111,
      113,  115,   40,   40,  117,   32,   40,   40,  116,   40,
       40,  119,   40,   40,   40,   44,   40,   40,  118,   40,
       40,   40,  122,   40,  120,   40,  121,   40,   40,  127,

       40,   40,   37,  125,   40,  123,   40,  124,   40,  126,
       40,   32,   40,   40,   40,   40,   40,  128,   40,   40,
       40,  129,   40,   40,  131,  130,   40,   40,   40,   40,
       40,  162,   40,   40,   40,  133,   40,  132,   40,  134,
       40,   40,  135,   40,   40,   40,   40,   40,   40,   40,
      136,   40,   40,   40,   40,   40,  137,  138,   40,   40,
       40,   40,  139,   40,   40,  140,   40,  141,   40,   40,
       40,   40,  143,   40,   40,  142,   40,   40,   40,   40,
       40,  144,   40,  146,   40,  148,   40,   40,   40,   30,
      145,   40,   40,   40,   40,   40,  147,  149,   40,  150,

       40,   40,   40,   40,  151,   40,  162,   40,   40,   40,
      152,  153,   40,   40,   40,  154,  155,  156,   40,   40,
       40,  162,   40,  162,   40,   40,   40,   40,   40,   40,
       40,  158,   40,   40,  157,   40,  159,   40,  160,   40,
      161,   40,   40,   40,   40,   40,  162,   40,   40,   31,
       31,   31,   31,   40,   40,   60,  162,   60,   60,    3,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,

      162,  162,  162
    } ;

static yyconst flex_int16_t yy_chk[504] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   12,   12,   25,   37,   16,   16,   33,
       37,   25,   12,   14,   14,   14,   16,   16,   33,   14,
      164,   37,   14,   14,   17,   17,   19,   19,   20,   20,
       14,   17,  111,   17,   17,   19,   19,   20,   20,   21,
       22,   21,   23,   23,   21,  110,   22,   21,   19,   23,
       27,   20,   22,   24,   24,   24,   27,   20,   26,   93,

       24,   40,   26,   29,   28,   28,   29,   40,   26,   28,
       43,   28,   29,   35,   35,   38,   39,   39,   35,   38,
       45,   39,   35,   41,   42,   41,   45,   41,   43,   35,
       38,   46,   39,   42,   43,   48,   47,   46,   39,   47,
       49,   48,   50,   52,   39,   47,   49,   53,   41,   52,
       50,   51,   49,   53,   41,   55,   50,   92,   51,   53,
       54,   91,   51,   56,   51,   55,   54,   54,   89,   57,
       59,   55,   57,   56,   58,   59,   59,   58,   57,   56,
       88,   67,   61,   58,   61,   61,   61,   62,   63,   62,
       71,   62,   63,   64,   61,   64,   68,   64,   66,   66,

       70,   65,   67,   63,   44,   68,   70,   66,   67,   72,
       73,   72,   74,   76,   74,   73,   73,   72,   75,   77,
       74,   77,   75,   76,   75,   78,   79,   77,   78,   76,
       81,   78,   79,   80,   80,   81,   81,   78,   79,   82,
       80,   96,   82,   83,   84,   82,   84,   83,   96,   83,
       84,   85,   85,   86,   96,   87,   87,   86,   85,   36,
       94,   34,   94,   86,   87,   90,   95,   90,   94,   90,
       95,   97,   95,   98,   99,   31,  103,   97,   98,   98,
      100,  101,  103,   97,   99,   18,  100,  104,  100,  101,
       99,  102,  105,  104,  102,  101,  104,  102,  105,  112,

      106,  107,   13,  108,  105,  106,  106,  107,  108,  109,
      112,    8,  113,  114,  108,  109,  112,  113,  113,  114,
      115,  116,  117,  118,  119,  117,  115,  116,  117,  118,
      119,    3,  120,  116,  121,  121,  119,  120,  120,  122,
      121,  123,  124,  125,  126,  127,  122,  123,  124,  125,
      126,  127,  122,  128,  124,  129,  128,  130,  131,  128,
      132,  129,  131,  130,  131,  133,  132,  134,  135,  130,
      136,  133,  137,  138,  135,  136,  136,  133,  134,  138,
      139,  140,  137,  142,  134,  144,  139,  141,  137,    2,
      141,  144,  140,  141,  142,  143,  143,  145,  140,  146,

      142,  143,  147,  145,  148,  146,    0,  148,  147,  145,
      149,  150,  149,  148,  150,  151,  152,  153,  149,  154,
      150,    0,  151,    0,  153,  154,  152,  156,  151,  155,
      153,  156,  152,  156,  155,  155,  157,  158,  159,  157,
      160,  160,  161,  158,  159,  157,    0,  160,  161,  163,
      163,  163,  163,  165,  165,  166,    0,  166,  166,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  162,  162,

      162,  162,  162
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int boot_yy_flex_debug;
int boot_yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *boot_yytext;
#line 1 "bootscanner.l"
#line 2 "bootscanner.l"
/*-------------------------------------------------------------------------
 *
 * bootscanner.l
 *	  a lexical scanner for the bootstrap parser
 *
 * Portions Copyright (c) 1996-2013, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 *
 * IDENTIFICATION
 *	  src/backend/bootstrap/bootscanner.l
 *
 *-------------------------------------------------------------------------
 */
#include "postgres.h"

#include "access/attnum.h"
#include "access/htup.h"
#include "access/itup.h"
#include "access/skey.h"
#include "access/tupdesc.h"
#include "bootstrap/bootstrap.h"
#include "catalog/pg_am.h"
#include "catalog/pg_attribute.h"
#include "catalog/pg_class.h"
#include "nodes/nodes.h"
#include "nodes/parsenodes.h"
#include "nodes/pg_list.h"
#include "nodes/primnodes.h"
#include "parser/scansup.h"
#include "rewrite/prs2lock.h"
#include "storage/block.h"
#include "storage/fd.h"
#include "storage/itemptr.h"
#include "storage/off.h"
#include "utils/rel.h"

/* Not needed now that this file is compiled as part of bootparse. */
/* #include "bootparse.h" */


/* Avoid exit() on fatal scanner errors (a bit ugly -- see yy_fatal_error) */
#undef fprintf
#define fprintf(file, fmt, msg)  fprintf_to_ereport(fmt, msg)

static void
fprintf_to_ereport(const char *fmt, const char *msg)
{
	ereport(ERROR, (errmsg_internal("%s", msg)));
}


static int	yyline = 1;			/* line number for error reporting */

#define YY_NO_INPUT 1
#line 694 "bootscanner.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int boot_yylex_destroy (void );

int boot_yyget_debug (void );

void boot_yyset_debug (int debug_flag  );

YY_EXTRA_TYPE boot_yyget_extra (void );

void boot_yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *boot_yyget_in (void );

void boot_yyset_in  (FILE * _in_str  );

FILE *boot_yyget_out (void );

void boot_yyset_out  (FILE * _out_str  );

			int boot_yyget_leng (void );

char *boot_yyget_text (void );

int boot_yyget_lineno (void );

void boot_yyset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int boot_yywrap (void );
#else
extern int boot_yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( boot_yytext, (size_t) boot_yyleng, 1, boot_yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( boot_yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( boot_yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, boot_yyin))==0 && ferror(boot_yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(boot_yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int boot_yylex (void);

#define YY_DECL int boot_yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after boot_yytext and boot_yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( boot_yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(boot_yytext[boot_yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! boot_yyin )
			boot_yyin = stdin;

		if ( ! boot_yyout )
			boot_yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			boot_yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				boot_yy_create_buffer(boot_yyin,YY_BUF_SIZE );
		}

		boot_yy_load_buffer_state( );
		}

	{
#line 75 "bootscanner.l"


#line 916 "bootscanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of boot_yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 163 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 162 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 77 "bootscanner.l"
{ return(OPEN); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 79 "bootscanner.l"
{ return(XCLOSE); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 81 "bootscanner.l"
{ return(XCREATE); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 83 "bootscanner.l"
{ return(OBJ_ID); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 84 "bootscanner.l"
{ return(XBOOTSTRAP); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 85 "bootscanner.l"
{ return(XSHARED_RELATION); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 86 "bootscanner.l"
{ return(XWITHOUT_OIDS); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 87 "bootscanner.l"
{ return(XROWTYPE_OID); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 88 "bootscanner.l"
{ return(NULLVAL); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 90 "bootscanner.l"
{ return(INSERT_TUPLE); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 92 "bootscanner.l"
{ return(COMMA); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 93 "bootscanner.l"
{ return(EQUALS); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 94 "bootscanner.l"
{ return(LPAREN); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 95 "bootscanner.l"
{ return(RPAREN); }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 97 "bootscanner.l"
{ yyline++; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 98 "bootscanner.l"
;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 99 "bootscanner.l"
;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 101 "bootscanner.l"
; /* drop everything after "#" for comments */
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 104 "bootscanner.l"
{ return(XDECLARE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 105 "bootscanner.l"
{ return(XBUILD); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 106 "bootscanner.l"
{ return(INDICES); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 107 "bootscanner.l"
{ return(UNIQUE); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 108 "bootscanner.l"
{ return(INDEX); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 109 "bootscanner.l"
{ return(ON); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 110 "bootscanner.l"
{ return(USING); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 111 "bootscanner.l"
{ return(XTOAST); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 113 "bootscanner.l"
{
					yylval.str = MapArrayTypeName(boot_yytext);
					return(ID);
				}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 117 "bootscanner.l"
{
					yylval.str = scanstr(boot_yytext);
					return(ID);
				}
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 121 "bootscanner.l"
{
					boot_yytext[strlen(boot_yytext)-1] = '\0'; /* strip off quotes */
					yylval.str = scanstr(boot_yytext+1);
					boot_yytext[strlen(boot_yytext)] = '"'; /* restore quotes */
					return(ID);
				}
	YY_BREAK
case 30:
#line 129 "bootscanner.l"
case 31:
#line 130 "bootscanner.l"
case 32:
YY_RULE_SETUP
#line 130 "bootscanner.l"
{
							yylval.str = pstrdup(boot_yytext);
							return(CONST_P);
						}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 135 "bootscanner.l"
{
					elog(ERROR, "syntax error at line %d: unexpected character \"%s\"", yyline, boot_yytext);
				}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 141 "bootscanner.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1152 "bootscanner.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed boot_yyin at a new source and called
			 * boot_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = boot_yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( boot_yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * boot_yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of boot_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					boot_yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			boot_yyrestart(boot_yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) boot_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 163 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 163 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 162);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					boot_yyrestart(boot_yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( boot_yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve boot_yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void boot_yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        boot_yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            boot_yy_create_buffer(boot_yyin,YY_BUF_SIZE );
	}

	boot_yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	boot_yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void boot_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		boot_yypop_buffer_state();
	 *		boot_yypush_buffer_state(new_buffer);
     */
	boot_yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	boot_yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (boot_yywrap()) processing, but the only time this flag
	 * is looked at is after boot_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void boot_yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	boot_yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE boot_yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) boot_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in boot_yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) boot_yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in boot_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	boot_yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with boot_yy_create_buffer()
 * 
 */
    void boot_yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		boot_yyfree((void *) b->yy_ch_buf  );

	boot_yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a boot_yyrestart() or at EOF.
 */
    static void boot_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	boot_yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then boot_yy_init_buffer was _probably_
     * called from boot_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void boot_yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		boot_yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void boot_yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	boot_yyensure_buffer_stack();

	/* This block is copied from boot_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from boot_yy_switch_to_buffer. */
	boot_yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void boot_yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	boot_yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		boot_yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void boot_yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)boot_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in boot_yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)boot_yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in boot_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE boot_yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) boot_yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in boot_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	boot_yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to boot_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       boot_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE boot_yy_scan_string (yyconst char * yystr )
{
    
	return boot_yy_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to boot_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE boot_yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) boot_yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in boot_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = boot_yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in boot_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up boot_yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		boot_yytext[boot_yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = boot_yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		boot_yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int boot_yyget_lineno  (void)
{
    
    return boot_yylineno;
}

/** Get the input stream.
 * 
 */
FILE *boot_yyget_in  (void)
{
        return boot_yyin;
}

/** Get the output stream.
 * 
 */
FILE *boot_yyget_out  (void)
{
        return boot_yyout;
}

/** Get the length of the current token.
 * 
 */
int boot_yyget_leng  (void)
{
        return boot_yyleng;
}

/** Get the current token.
 * 
 */

char *boot_yyget_text  (void)
{
        return boot_yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void boot_yyset_lineno (int  _line_number )
{
    
    boot_yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see boot_yy_switch_to_buffer
 */
void boot_yyset_in (FILE *  _in_str )
{
        boot_yyin = _in_str ;
}

void boot_yyset_out (FILE *  _out_str )
{
        boot_yyout = _out_str ;
}

int boot_yyget_debug  (void)
{
        return boot_yy_flex_debug;
}

void boot_yyset_debug (int  _bdebug )
{
        boot_yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from boot_yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    boot_yyin = stdin;
    boot_yyout = stdout;
#else
    boot_yyin = NULL;
    boot_yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * boot_yylex_init()
     */
    return 0;
}

/* boot_yylex_destroy is for both reentrant and non-reentrant scanners. */
int boot_yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		boot_yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		boot_yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	boot_yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * boot_yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *boot_yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *boot_yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void boot_yyfree (void * ptr )
{
			free( (char *) ptr );	/* see boot_yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 141 "bootscanner.l"



void
yyerror(const char *message)
{
	elog(ERROR, "%s at line %d", message, yyline);
}

